#All R code provided is the intellectual property of Caloo Ecological Services. It is to 
#be used solely for the stated purpose (Adrian Tait's email of 01/10/2014 to Andrea
#Taylor, Xodus) of allowing MSS, SNH and JNCC to check the calculations of 
#collision risk mortality against the standard calculations in the downloadable excel 
#spreadsheets. It is only to be used in the context of determining consent with respect
#to the Hywind Scotland Pilot Park project and is not to be shared with organisations
#outside MS-LOT, MSS, SNH and JNCC.
##################################################################################################################################
#                                                                                                                                #
#   Running this R file as source provides the collision risk estimates for each of the scenarios described in the README file.  #
#                                                                                                                                #     
##################################################################################################################################                                                

# CHANGE WORK DIRECTORY GIVEN HERE TO APPROPRIATE SETTING FOR OWN MACHINE
setwd("C:/Documents and Settings/Nigel/My Documents/Hywind/R/SharedCode")
#
rm(list=ls())
source("Hywind.functions.to.share.r")

############################################################################################################################
# Scenarios 1 and 2 : Basic collision risk model using fixed Q2r value of 28.1%                                            #
############################################################################################################################
#
#  Scenario 1: stage 1 code identical to Bands                                                                                        
out1<-run.monthly.SOSS.collision.risk.model(parameters.file="HywindSOSSParameters.csv",scenario=1)
out1$overall$n.collision.no.avoidance # 5814 collisions per year assuming no avoidance from R code and standard spreadsheet
#
# Scenario 2: stage 2 improved code
out2<-run.monthly.SOSS.collision.risk.model(parameters.file="HywindSOSSParameters.csv",scenario=2)
out2$overall$n.collision.no.avoidance # 5814 collisions per year assuming no avoidance from R code and standard spreadsheet
############################################################################################################################
############################################################################################################################



############################################################################################################################
# Scenarios 3 and 4 : Basic collision risk modelling using Q2r value estimated from flight height distribution             #
############################################################################################################################
#
#  Scenario 3: stage 1 code identical to Bands                                                                                        
out3<-run.monthly.SOSS.collision.risk.model(parameters.file="HywindSOSSParameters.csv",scenario=3)
out3$overall$n.collision.no.avoidance # 2618 collisions per year assuming no avoidance from R code and standard spreadsheet
out3$overall$Q2r # 12.7% of collisions at rotor swept height from R code and standard spreadsheet
#
# Scenario 4: stage 2 improved code
out4<-run.monthly.SOSS.collision.risk.model(parameters.file="HywindSOSSParameters.csv",scenario=4)
out4$overall$n.collision.no.avoidance # 2602 collisions per year assuming no avoidance compared to 2618 collisions from Band Code
out4$overall$Q2r # 12.6 of collisions at rotor swept height compared to 12.7% based on Band calculation
out4$overall$n.collision.no.avoidance*out3$overall$Q2r/out4$overall$Q2r #Correcting for slight difference in Q2r gives identical result to Scenario 3
############################################################################################################################
############################################################################################################################



############################################################################################################################
# Scenarios 5 and 6: Extended collision risk modelling                                                                     #
############################################################################################################################
#
#  Scenario 5: stage 1 code identical to Bands                                                                                        
out5<-run.monthly.SOSS.collision.risk.model(parameters.file="HywindSOSSParameters.csv",scenario=5)
out5$overall$n.collision.no.avoidance # 1473 collisions per year assuming no avoidance from both R code and standard spreadsheet
out5$overall$Q2r # 12.7% of collisions at rotor swept height identical to standard spreadsheet
out5$overall$flux.integral   #flux integral of 0.0823 identical to standard spreadsheet
out5$overall$collision.integral # collision integral of 0.01110 identical to standard spreadsheet
out5$overall$p.of.vulnerable.birds.through.rotor # 51.1% of birds at rotor swept height estimated to fly through rotor
out5$overall$average.p.collide # For those birds that do fly through rotor, probability of collision of 13.5%, identical to standard spreadsheet
#
# Scenario 6: stage 2 improved code
out6<-run.monthly.SOSS.collision.risk.model(parameters.file="HywindSOSSParameters.csv",scenario=6)
out6$overall$n.collision.no.avoidance # 1505 collisions per year assuming no avoidance compared to 1473 collisions from Band code
out6$overall$Q2r # 12.6% of collisions at rotor swept height compared to 12.7% based on Band code. 
out6$overall$p.of.vulnerable.birds.through.rotor # 53.1% of birds at rotor swept height estimated to fly through rotor compared to 51.1% for Band Code
out6$overall$average.p.collide # For those birds that do fly through rotor, probability of collision of 13.3%, compared to 13.5% for Band code
############################################################################################################################
############################################################################################################################



############################################################################################################################
# Scenarios 7 and 8: Extended collision risk modelling with a uniform flight height distribution                           #
############################################################################################################################
pi/4 # Expectation of proportion of vulnerable birds (i.e. at rotor swept height) flying through turbines if uniformly distributed across flight heights
#  Scenario 7: stage 1 code identical to Bands                                                                                        
out7<-run.monthly.SOSS.collision.risk.model(parameters.file="HywindSOSSParameters.csv",scenario=7)
out7$overall$Q2r 
out7$overall$p.of.vulnerable.birds.through.rotor
#
# Scenario 8: stage 2 improved code
out8<-run.monthly.SOSS.collision.risk.model(parameters.file="HywindSOSSParameters.csv",scenario=8)
out8$overall$Q2r 
out8$overall$p.of.vulnerable.birds.through.rotor
############################################################################################################################
############################################################################################################################


#
# WRITE ANNUAL COLLISION RISK MORTALITY ESTIMATES FOR ALL SCENARIOS TO SINGLE FILE
#
overall<-rbind(out1$overall,out2$overall,out3$overall,out4$overall,out5$overall,out6$overall,out7$overall,out8$overall)
write.csv(overall,"overall.csv")

